summaryrefslogtreecommitdiffstats
path: root/qa/tasks/ceph.py
diff options
context:
space:
mode:
Diffstat (limited to 'qa/tasks/ceph.py')
-rw-r--r--qa/tasks/ceph.py4
1 files changed, 3 insertions, 1 deletions
diff --git a/qa/tasks/ceph.py b/qa/tasks/ceph.py
index 6314183c3b3..706ea6b89f1 100644
--- a/qa/tasks/ceph.py
+++ b/qa/tasks/ceph.py
@@ -990,7 +990,9 @@ def cluster(ctx, config):
try:
remote.run(args=['yes', run.Raw('|')] + ['sudo'] + mkfs + [dev])
except run.CommandFailedError:
- # Newer btfs-tools doesn't prompt for overwrite, use -f
+ if fs != 'btrfs':
+ raise
+ # Newer btrfs-tools doesn't prompt for overwrite, use -f
if '-f' not in mount_options:
mkfs_options.append('-f')
mkfs = ['mkfs.%s' % fs] + mkfs_options